/**
 * Copyright (c) Tiny Technologies, Inc. All rights reserved.
 * Licensed under the LGPL or a commercial license.
 * For LGPL see License.txt in the project root for license information.
 * For commercial licenses see https://www.tiny.cloud/
 */

enum ItemResponse { CLOSE_ON_EXECUTE, BUBBLE_TO_SANDBOX }

export default ItemResponse;